@@ -3,16 +3,16 @@
 #' The purpose of \code{seqTrans} is to spot impossible transitions
 #' in longitudinal categorical data.
 #'
-#' @param data a data frame containing sequences of a multinomial 
+#' @param data a data frame containing sequences of a multinomial
 #' variable with missing data (coded as \code{NA})
-#' @param var the list of columns containing the trajectories. 
-#' Default is NULL, i.e. all the columns. 
-#' @param trans \code{character} vector gathering the impossible transitions. 
+#' @param var the list of columns containing the trajectories.
+#' Default is NULL, i.e. all the columns.
+#' @param trans \code{character} vector gathering the impossible transitions.
 #' For example: trans <- c("1->3","1->4","2->1","4->1","4->3")
 #'
 #' @author Andre Berchtold and Kevin Emery
 #'
-#' @return It returns a matrix where each row is the position of an 
+#' @return It returns a matrix where each row is the position of an
 #' impossible transition.
 #'
 #' @examples
@@ -70,33 +70,33 @@
 #' @importFrom foreach foreach
 #' @importFrom foreach %dopar%
 #'
+#' @importFrom parallelly availableCores
+#'
 #' @export
 seqTrans <- function(data, var = NULL, trans) {
-  
   data <- dataxtract(data, var)
-  
-  
+
+
   impTrans <- trans
   nr <- nrow(data)
   nc <- ncol(data)
 
 
- 
+
   dataClass <- class(data[1, 1])
-  if ((dataClass != "factor") & (dataClass != "character") 
-      & (dataClass != "numeric")) {
+  if ((dataClass != "factor") & (dataClass != "character") &
+    (dataClass != "numeric")) {
     stop("/!\\ The class of the variables contained in your original dataset
          should be either 'factor', 'character', or 'numeric'")
   }
 
 
-  if (dataClass == "factor"|dataClass=="character") {
+  if (dataClass == "factor" | dataClass == "character") {
     k <- length(sort(unique(as.vector(as.matrix(data)))))
   } else {
     k <- max(data)
   }
 
-  # rows with NA
   i <- 1
   numbOfNAFilledLines <- 0
   while (i <= nrow(data)) {
@@ -106,39 +106,21 @@ seqTrans <- function(data, var = NULL, trans) {
     }
     i <- i + 1
   }
-  # Updating the number of rows in data
   nr <- nrow(data)
 
 
   for (i in 1:length(impTrans)) {
     if (!str_detect(impTrans[i], "->")) {
-      stop("/!\\ Warning, you should construct your transition(s) vector trans 
-        with little arrows as 
+      stop("/!\\ Warning, you should construct your transition(s) vector trans
+        with little arrows as
         follow: trans <- c('...->...', '...->...', etc.).")
     }
-    # Testing if we are effectively analyzing a transition or not
     locDash <- str_locate(impTrans[i], "-")
     firstState <- substr(impTrans[i], 1, locDash - 1)
     locSpike <- str_locate(impTrans[i], ">")
     secondState <- substr(impTrans[i], locSpike + 1, nchar(impTrans[1]))
- 
   }
 
-
-
-
-
-
-
-
-
-  # 3. Spotting impossible transitions ----------------------------
-
-
-  ## Setup
-  #
-  # Transforming every line of data into class character and adding a dash 
-  # inbetween every state
   dashes <- replicate(nc, "->")
   CharAndDashes <- function(data) {
     mytestChar <- paste(as.vector(rbind(data, dashes)), collapse = "")
@@ -147,11 +129,6 @@ seqTrans <- function(data, var = NULL, trans) {
 
 
 
-
-
-
-  # 3.1 Number of listed impossible transitions -------------------------------
-  # Identifying the patterns of the impossible transitions in each line of data
   countImpTrans <- function(dataCharAndDashes) {
     str_count(dataCharAndDashes, pattern = paste0("(?=", impTrans, ")"))
   }
@@ -161,8 +138,7 @@ seqTrans <- function(data, var = NULL, trans) {
   } else {
     numbOfImpTrans <- sum(numbOfImpTransByRow)
   }
-  # Interrupting the program in case no impossible transitions among impTrans 
-  # have been found
+
   if (sum(numbOfImpTrans) == 0) {
     message("Your dataset has no impossible transitions!")
 
@@ -180,14 +156,9 @@ seqTrans <- function(data, var = NULL, trans) {
 
 
 
-  # we will have "3 14" in place i,j
   startLocMat <- matrix(NA, nrow = length(impTrans), ncol = nrow(data))
   for (i in 1:length(impTrans)) {
-    # We need this roundabout with "(?=)" because in the case of a transition
-    # yes->yes->yes for example, if the user is interested in the transition
-    # yes->yes, the simple version without "(?=)" won't spot
-    # the second transtion because a part of it is used in the first one.
-    Tmplist <- str_locate_all(dataCharAndDashes, paste0("(?=",impTrans[i],")"))
+    Tmplist <- str_locate_all(dataCharAndDashes, paste0("(?=", impTrans[i], ")"))
     for (j in 1:length(dataCharAndDashes)) {
       tempMat <- Tmplist[[j]]
       if (nrow(tempMat) > 0) {
@@ -201,19 +172,11 @@ seqTrans <- function(data, var = NULL, trans) {
 
 
 
-  # Function to extract the different digits when a string is composed
-  # of multiple digits
+
   Numextract <- function(string) {
     unlist(regmatches(string, gregexpr("[[:digit:]]+\\.*[[:digit:]]*", string)))
   }
-  # Function that translates the value corresponding to where the transition
-  # occures in the string to where it occures in a observation
-  # To do so, we extract the substring until the desired a transition occures
-  # in the string and we compute the number +1 of ">" in this substring.
-  # For example, if the observation j is of the form "yes->yes->no->yes->yes"
-  # and the value 15 is stored in StartLocMat, we extract the substring
-  # "yes->yes->no->", we compute 3 + 1. The target transition therefore occurs
-  # in position 4.
+
   GetRealColPosition <- function(dataCharAndDashes, RowPos, ColPos) {
     dataCharAndDashesSubstring <- substr(dataCharAndDashes[RowPos], 1, ColPos)
     realColPosition <- str_count(dataCharAndDashesSubstring, pattern = ">") + 1
@@ -231,9 +194,14 @@ seqTrans <- function(data, var = NULL, trans) {
           detectTemp <- str_detect(startLocMat[i, j], " ")
           if (detectTemp == FALSE) {
             TmpRows <- c(TmpRows, j)
-            TmpCols <- c(TmpCols, 
-              GetRealColPosition(dataCharAndDashes = dataCharAndDashes, 
-              RowPos = j, ColPos = as.numeric(startLocMat[i, j])))
+            TmpCols <- c(
+              TmpCols,
+              GetRealColPosition(
+                dataCharAndDashes = dataCharAndDashes,
+                RowPos = j,
+                ColPos = as.numeric(startLocMat[i, j])
+              )
+            )
           } else {
             hiddenCol <- str_count(startLocMat[i, j], " ")
             TmpRows <- c(TmpRows, rep(j, hiddenCol + 1))
@@ -241,8 +209,9 @@ seqTrans <- function(data, var = NULL, trans) {
             TmpVec <- c()
             for (k in 1:length(extractedNumbers)) {
               TmpVec[k] <- GetRealColPosition(
-                dataCharAndDashes=dataCharAndDashes, 
-                RowPos = j, ColPos = as.numeric(extractedNumbers[k]))
+                dataCharAndDashes = dataCharAndDashes,
+                RowPos = j, ColPos = as.numeric(extractedNumbers[k])
+              )
             }
             TmpCols <- c(TmpCols, TmpVec)
           }
@@ -258,21 +227,7 @@ seqTrans <- function(data, var = NULL, trans) {
 
   rowMat <- matrix(NA, length(impTrans), MaxNumTransitions)
   colMat <- matrix(NA, length(impTrans), MaxNumTransitions)
-  #
-  # # Converting into a dataframe
-  # rowMat <- as.data.frame(rowMat)
-  # # Renaming the columns of rowMat
-  # colnames_rowMat <- paste(1:ncol(rowMat),")",sep='')
-  # rownames(rowMat) <- impTrans
-  # colnames(rowMat) <- colnames_rowMat
-  #
-  # # Converting into a dataframe
-  # colMat <- as.data.frame(colMat)
-  # # Renaming the columns of colMat
-  # colnames_colMat <- paste(1:ncol(colMat),")",sep='')
-  # rownames(colMat) <- impTrans
-  # colnames(colMat) <- colnames_colMat
-  #
+
   for (i in 1:length(impTrans)) {
     if (numbOfImpTrans[i] > 0) {
       rowMat[i, 1:length(list_rows[[i]])] <- list_rows[[i]]
@@ -285,13 +240,10 @@ seqTrans <- function(data, var = NULL, trans) {
     colMat <- colMat[rowSums(!is.na(colMat)) > 0, ]
   }
 
-
-
-  # 3.3 Summary data frame --------------------------------------------------
-  #
-  # Update of impTrans with an arrow
-  impTransOverview <- data.frame(c(impTrans, "", "Total:"), 
-    c(numbOfImpTrans, "", sum(numbOfImpTrans)))
+  impTransOverview <- data.frame(
+    c(impTrans, "", "Total:"),
+    c(numbOfImpTrans, "", sum(numbOfImpTrans))
+  )
   colnames(impTransOverview) <- c("Transitions", "Occurence")
 
   if (length(rowMat) > 0) {
